@@ -29,23 +29,23 @@ mod tests {
   "overlays": [
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/character_encoding/1.0",
+      "type": "spec/overlays/character_encoding/1.0",
       "default_character_encoding": "utf-8",
       "attr_character_encoding": { "n2": "iso-8859-1" }
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/unit/1.0",
+      "type": "spec/overlays/unit/1.0",
       "attr_units": { "n1": "days" }
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/entry_code/1.0",
+      "type": "spec/overlays/entry_code/1.0",
       "attr_entry_codes": { "n1": [ "op1", "op2" ] }
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/label/1.0",
+      "type": "spec/overlays/label/1.0",
       "language": "pl_PL",
       "attr_labels": { "n1": "Imię: ", "n2": "Data: " },
       "attr_categories": [ "_cat-1_" ],
@@ -54,19 +54,19 @@ mod tests {
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/information/1.0",
+      "type": "spec/overlays/information/1.0",
       "language": "pl_PL",
       "attr_information": { "n1": "info pl" }
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/entry/1.0",
+      "type": "spec/overlays/entry/1.0",
       "language": "pl_PL",
       "attr_entries": { "n1": { "op2": "Opcja 2", "op1": "Opcja 1" } }
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/label/1.0",
+      "type": "spec/overlays/label/1.0",
       "language": "en_EN",
       "attr_labels": { "n2": "Date: ", "n1": "Name: " },
       "attr_categories": [ "_cat-1_" ],
@@ -75,31 +75,31 @@ mod tests {
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/information/1.0",
+      "type": "spec/overlays/information/1.0",
       "language": "en_EN",
       "attr_information": { "n1": "info en" }
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/entry/1.0",
+      "type": "spec/overlays/entry/1.0",
       "language": "en_EN",
       "attr_entries": { "n1": { "op1": "Option 1", "op2": "Option 2" } }
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/format/1.0",
+      "type": "spec/overlays/format/1.0",
       "attr_formats": { "n2": "DD/MM/YYYY" }
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/meta/1.0",
+      "type": "spec/overlays/meta/1.0",
       "language": "en_EN",
       "name": "Driving Licence",
       "description": "DL desc"
     },
     {
       "capture_base": "EP20A21C9EHJu8fOOrjV4ywgn6bGFQbQ3cfWFwWL57io",
-      "type": "spec/overalys/meta/1.0",
+      "type": "spec/overlays/meta/1.0",
       "language": "pl_PL",
       "name": "Prawo Jazdy",
       "description": "PJ desc"
